﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO.Ports; // abych mohl ziskat porty jimiz komp disponuje
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace SerialPortReceiver
{
    public partial class FormSerialPortReceiver : Form
    {
        /* konstruktor teto tridy volany z funkce main */
        public FormSerialPortReceiver()
        {
            InitializeComponent();
            // ziskam pole seriovych portu jimiz komp disponuje a pridam do comboboxu
            string[] ports = SerialPort.GetPortNames();
            cbPortSelector.Items.AddRange(ports);
            // baud rates podporovane vetsinou com portu
            string[] baudrates = new string[10] { "2400", "4800", "9600", "14400", "19200", "28800", "38400", "56000", "57600", "115200" };
            cbBaudSelector.Items.AddRange(baudrates);
            // zakazu editovani textu vybrane polozky v comboboxu uzivatelem (mozno udelat i v designu vpravo dole v properties)
            cbPortSelector.DropDownStyle = ComboBoxStyle.DropDownList;
            cbBaudSelector.DropDownStyle = ComboBoxStyle.DropDownList;
            // pokud josu dostupne nejake porty, tak se vybere ten z minula (pokud je dostupny) nebo prvni dostupny
            if (ports.Length > 0)
            {
                if (ports.Contains(Properties.Settings.Default.PortName))
                {
                    cbPortSelector.SelectedItem = Properties.Settings.Default.PortName;
                }
                else
                {
                    cbPortSelector.SelectedItem = ports[0];
                }
            }
            // bud se vybere ten z minula a pokud nebylo zande minule nebo se ulozila sracka, da se 9600
            if (baudrates.Contains(Properties.Settings.Default.BaudRate))
            {
                cbBaudSelector.SelectedItem = Properties.Settings.Default.BaudRate;
            }
            else
            {
                cbBaudSelector.SelectedItem = baudrates[2];
            }
        }
       
        // po stisknuti Připojit/Odpojit
        private void btConnection_Click(object sender, EventArgs e)
        {
            try
            {
                if (btConnection.Text == "Připojit")
                {
                    spReceiver.PortName = cbPortSelector.SelectedItem.ToString();
                    spReceiver.BaudRate = int.Parse(cbBaudSelector.SelectedItem.ToString());
                    spReceiver.Open();
                    timerChecker.Enabled = true;
                    btConnection.Text = "Odpojit";
                }
                else 
                {
                    spReceiver.Close();
                    timerChecker.Enabled = false;
                    btConnection.Text = "Připojit";
                }

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }

        }

        // po tiknuti timeru
        private void timerChecker_Tick(object sender, EventArgs e)
        {
            if (spReceiver.BytesToRead > 0)
            {
                tbCurReceived.Text = spReceiver.ReadExisting();
                // zavolam funci na zpracovani dat
            }
            else 
            {
                tbCurReceived.Text = "Nic se nepřijímá";
            }
        }


        // po zavreni formulare
        private void FormSerialPortReceiver_FormClosed(object sender, FormClosedEventArgs e)
        {
            if (spReceiver.IsOpen)
            {
                spReceiver.Close();
            }
            Properties.Settings.Default.PortName = cbPortSelector.SelectedItem.ToString();
            Properties.Settings.Default.BaudRate = cbBaudSelector.SelectedItem.ToString();
            Properties.Settings.Default.Save();
        }
    }
}
